@@ -1,4 +1,4 @@
-from pn import PetriNet
+from . pn import PetriNet
 
 
 
